@@ -27,14 +27,14 @@ import (
 	"os"
 	"path"
 
-	"github.com/rancher/k3d/v5/cmd/util"
-	cliconfig "github.com/rancher/k3d/v5/cmd/util/config"
-	"github.com/rancher/k3d/v5/pkg/client"
-	"github.com/rancher/k3d/v5/pkg/config"
-	l "github.com/rancher/k3d/v5/pkg/logger"
-	"github.com/rancher/k3d/v5/pkg/runtimes"
-	k3d "github.com/rancher/k3d/v5/pkg/types"
-	k3dutil "github.com/rancher/k3d/v5/pkg/util"
+	"github.com/k3d-io/k3d/v5/cmd/util"
+	cliconfig "github.com/k3d-io/k3d/v5/cmd/util/config"
+	"github.com/k3d-io/k3d/v5/pkg/client"
+	"github.com/k3d-io/k3d/v5/pkg/config"
+	l "github.com/k3d-io/k3d/v5/pkg/logger"
+	"github.com/k3d-io/k3d/v5/pkg/runtimes"
+	k3d "github.com/k3d-io/k3d/v5/pkg/types"
+	k3dutil "github.com/k3d-io/k3d/v5/pkg/util"
 
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
