@@ -24,14 +24,14 @@ package cluster
 import (
 	"time"
 
-	"github.com/rancher/k3d/v5/cmd/util"
-	"github.com/rancher/k3d/v5/pkg/client"
-	"github.com/rancher/k3d/v5/pkg/runtimes"
-	"github.com/rancher/k3d/v5/pkg/types"
+	"github.com/k3d-io/k3d/v5/cmd/util"
+	"github.com/k3d-io/k3d/v5/pkg/client"
+	"github.com/k3d-io/k3d/v5/pkg/runtimes"
+	"github.com/k3d-io/k3d/v5/pkg/types"
 	"github.com/spf13/cobra"
 
-	l "github.com/rancher/k3d/v5/pkg/logger"
-	k3d "github.com/rancher/k3d/v5/pkg/types"
+	l "github.com/k3d-io/k3d/v5/pkg/logger"
+	k3d "github.com/k3d-io/k3d/v5/pkg/types"
 )
 
 // NewCmdClusterStart returns a new cobra command
@@ -58,6 +58,17 @@ func NewCmdClusterStart() *cobra.Command {
 						l.Log().Fatalf("failed to gather info about cluster environment: %v", err)
 					}
 					startClusterOpts.EnvironmentInfo = envInfo
+
+					// Get pre-defined clusterStartOpts from cluster
+					fetchedClusterStartOpts, err := client.GetClusterStartOptsFromLabels(c)
+					if err != nil {
+						l.Log().Fatalf("failed to get cluster start opts from cluster labels: %v", err)
+					}
+
+					// override only a few clusterStartOpts from fetched opts
+					startClusterOpts.HostAliases = fetchedClusterStartOpts.HostAliases
+
+					// start the cluster
 					if err := client.ClusterStart(cmd.Context(), runtimes.SelectedRuntime, c, startClusterOpts); err != nil {
 						l.Log().Fatalln(err)
 					}
