@@ -33,10 +33,10 @@ import (
 	"github.com/docker/go-connections/nat"
 	"github.com/go-test/deep"
 	"github.com/imdario/mergo"
-	l "github.com/rancher/k3d/v5/pkg/logger"
-	"github.com/rancher/k3d/v5/pkg/runtimes"
-	"github.com/rancher/k3d/v5/pkg/types"
-	k3d "github.com/rancher/k3d/v5/pkg/types"
+	l "github.com/k3d-io/k3d/v5/pkg/logger"
+	"github.com/k3d-io/k3d/v5/pkg/runtimes"
+	"github.com/k3d-io/k3d/v5/pkg/types"
+	k3d "github.com/k3d-io/k3d/v5/pkg/types"
 	"github.com/spf13/viper"
 	"gopkg.in/yaml.v2"
 )
